package come.stormborntales.notevault.ui.viewmodel

import android.content.Context
import android.net.Uri
import android.util.Log
import android.webkit.MimeTypeMap
import androidx.lifecycle.ViewModel
import androidx.lifecycle.asLiveData
import androidx.lifecycle.viewModelScope
import come.stormborntales.notevault.data.local.entity.NoteEntity
import come.stormborntales.notevault.data.repository.NoteRepository
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import java.io.File

class NoteViewModel(
    private val repository: NoteRepository,
) : ViewModel() {
    val notes = repository.allNotes.asLiveData()

    fun addNote(context: Context, title: String, composer: String?, year: Int?, genre: String?, description: String?, selectedUris: List<Uri>, onDone:() -> Unit) {
        viewModelScope.launch(Dispatchers.IO) {
            val copiedUris = selectedUris.mapNotNull { uri ->
                try {
                    val inputStream = context.contentResolver.openInputStream(uri)
                    val extension = MimeTypeMap.getSingleton()
                        .getExtensionFromMimeType(context.contentResolver.getType(uri)) ?: "jpg"

                    val outputFile = File(context.filesDir, "note_${System.currentTimeMillis()}.$extension")
                    inputStream?.use { input ->
                        outputFile.outputStream().use { output ->
                            input.copyTo(output)
                        }
                    }
                    Log.d("NoteViewModel", "NoteEntityFile" + outputFile.absolutePath)
                    Uri.fromFile(outputFile).toString() // speichern als String
                } catch (e: Exception) {
                    e.printStackTrace()
                    null
                }
            }

            if (copiedUris.isNotEmpty()) {
                val note = NoteEntity(
                    title = title,
                    images = copiedUris, // muss als List<String> gespeichert sein
                    composer = composer,
                    year = year,
                    genre = genre,
                    description = description
                )

                repository.insert(note)
            }

            onDone()
        }
    }

    fun deleteNote(note: NoteEntity) {
        viewModelScope.launch {
            repository.delete(note)
        }
    }
}
